BasePickerModel class abstract

Implementers

Constructors

BasePickerModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

currentLeftIndex() → int
currentMiddleIndex() → int
currentRightIndex() → int
finalTime() → DateTime?
layoutProportions() → List<int>
leftDivider() → String
leftStringAtIndex(int index) → String?
middleStringAtIndex(int index) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rightDivider() → String
rightStringAtIndex(int index) → String?
setLeftIndex(int index) → void
setMiddleIndex(int index) → void
setRightIndex(int index) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited